MantleSizes class

A scale for managing size tokens.

Constructors

MantleSizes(Set<String> sizes)
Creates a new size scale with the given sizes.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createScale<T>(Map<String, T> scale) MantleSizeScale<T>
Creates a new size scale with the given scale.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String size) String
Returns the size for the given key, or throws an error if not found.