mantle_core library
Classes
- BreakpointBuilder
- A widget that builds its child based on the current breakpoint.
- Icon
- A widget that displays an icon from the Mantle icon set.
- Mantle
- A class that provides access to the current (root) Mantle theme.
- MantleBreakpoint
- A group of breakpoints for different sizes.
- MantleColorAccessor
- A class for accessing the colors of the current Mantle theme.
- MantleColors
- A group of color tokens for the Mantle design system.
- MantleHeadings
- Represents the heading styles for different levels.
- MantleIcons
- A group of icons used troughout the app
- MantleProvider
- A widget that provides a Mantle theme to its descendants.
- MantleRadius
- A class for managing radius values based on a size scale.
- MantleShadow
- MantleSizes
- A scale for managing size tokens.
-
MantleSizeScale<
T> - A scale for managing size tokens.
- MantleSpacing
- A class for managing spacing values based on a size scale.
- MantleTheme
- Base class for all Mantle themes.
- MantleTokenGroup
- Common operations for immutable token groups attached to a theme.
- MantleTypography
- Represents the typography tokens for the Mantle design system.
Enums
- MantleAspect
- An enumeration of the different aspects of the Mantle theme.
Extension Types
- MantleColor
- A group of colors representing different shades of the same hue.
Extensions
-
MantleSizeScaleLerper
on MantleSizeScale<
T> - Extension for lerping between size scales.
Typedefs
- IconTokenBuilder = Widget Function({Color color, double size})
- A function that builds an icon widget with optional size and color parameters.
- MantleSize = String
- A type alias for defining size tokens.