MantleTypography class
Typography tokens for the Mantle design system.
- Implemented types
Constructors
-
MantleTypography({required String fontFamily, required String fontFamilyMono, required MantleSizeScale<
double> fontSize, required MantleHeadings headings, required TextStyle body, required TextStyle label, required MantleSizeScale<double> lineHeight}) -
Creates typography tokens.
const
- MantleTypography.empty()
-
An empty group that yields to the other side in mergeWith.
const
Properties
- body → TextStyle
-
The style for the body text.
final
- fontFamily → String
-
The font family for the typography.
final
- fontFamilyMono → String
-
The font family for the monospace typography.
final
-
fontSize
→ MantleSizeScale<
double> -
The font sizes for the typography.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headings → MantleHeadings
-
The heading styles for the typography.
final
- isEmpty → bool
-
Whether this group carries no author-provided values.
no setter
- label → TextStyle
-
The style for the label text.
final
-
lineHeight
→ MantleSizeScale<
double> -
The line heights for the typography.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
lerpWith(
covariant MantleTypography other, double t) → MantleTypography -
Linearly interpolates between this group and
other.override -
mergeWith(
covariant MantleTypography other) → MantleTypography -
Returns a new group that combines this instance with
other.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited